""""Include local template

"""


def get_templates(alias: str, templates: list[str]):
    """Collect reference templates from files

    Parameters
    ----------
    alias : str
        Alias name will be patched as prefix of include template

    """
    pass
